.. _troubleshooting-label:

Troubleshooting
===============

*PAIREF* just hangs in command line. Nothing is going on.
  This can happen on MS Windows. Press Enter or click in the *CCP4CONSOLE* window, the process will continue.
